LENT_MASSES = ('Sicut oculi', 'Domine refugium', 'Reminíscere', 'Confessio',
               'De necessitatibus', 'Intret oratio', 'Redime me', 'Tibi dixit',
               'Ne derelinquas me', 'Deus, in adjutorium', 'Ego autem',
               'Lex Domini', 'In Deo laudabo', 'Ego clamavi', 'Ego autem',
               'Salus populi', 'Fac mecum', 'Verba mea', 'Deus, in nomine',
               'Exaudi, Deus', 'Cum sanctificatus', 'Lætetur cor', 'Meditatio',
               'Sitientes', 'Miserere mihi', 'Expecta Dominum',
               'Liberator meus', 'Omnia, quæ fecisti', 'Miserere mihi',
               'Miserere mihi',)

# begins with the 4th Sunday after Pentecost
PENTECOST_MASSES = (
                    'Dóminus illuminátio', #  4
                    'Exaudi, Domine',      #  5
                    'Dominus fortitudo',   #  6
                    'Omnes gentes',        #  7
                    'Suscepimus',          #  8
                    'Ecce Deus',           #  9
                    'Cum clamarem',        # 10
                    'Deus in loco',        # 11
                    'Deus in adjutorium',  # 12
                    'Respice Domine',      # 13
                    'Protector noster',    # 14
                    'Inclina Domine',      # 15
                    'Miserere mihi',       # 16
                    'Justus es',           # 17
                    'Da pacem',            # 18
                    'Salus populi',        # 19
                    'Omnia',               # 20
                    'In voluntate tua',    # 21
                    'Si iniquitates',      # 22
                    'Dicit Dominus',       # 23
                    'Dicit Dominus',       # ..
                    'Dicit Dominus',       # ..
                    'Dicit Dominus',       # ..
                    'Dicit Dominus',       # ..
                    'Dicit Dominus',       # 24
)

EPIPHANY_MASSES = ('', )
