from datetime import datetime
from ordotools import LiturgicalCalendar

def test_basic():
    assert LiturgicalCalendar(int(datetime.today().strftime("%Y")), "roman")
    assert LiturgicalCalendar(2024, "roman")
    assert LiturgicalCalendar(2025, "roman")
    assert LiturgicalCalendar(2026, "roman")
    assert LiturgicalCalendar(2027, "roman")
    assert LiturgicalCalendar(2028, "roman")
    assert LiturgicalCalendar(2029, "roman")
    assert LiturgicalCalendar(2030, "roman")
    assert LiturgicalCalendar(2031, "roman")
    assert LiturgicalCalendar(2032, "roman")
    assert LiturgicalCalendar(2033, "roman")
    assert LiturgicalCalendar(2034, "roman")
    assert LiturgicalCalendar(2035, "roman")
    assert LiturgicalCalendar(2036, "roman")
    assert LiturgicalCalendar(2037, "roman")
    assert LiturgicalCalendar(2038, "roman")
    assert LiturgicalCalendar(2039, "roman")
    assert LiturgicalCalendar(2040, "roman")
    assert LiturgicalCalendar(2041, "roman")
    assert LiturgicalCalendar(2042, "roman")
    assert LiturgicalCalendar(2043, "roman")
    assert LiturgicalCalendar(2044, "roman")
    assert LiturgicalCalendar(2045, "roman")
    assert LiturgicalCalendar(2046, "roman")
    assert LiturgicalCalendar(2047, "roman")
    assert LiturgicalCalendar(2048, "roman")
    assert LiturgicalCalendar(2049, "roman")
    assert LiturgicalCalendar(2050, "roman")
    assert LiturgicalCalendar(2051, "roman")
    assert LiturgicalCalendar(2052, "roman")
    assert LiturgicalCalendar(2053, "roman")
    assert LiturgicalCalendar(2054, "roman")
    assert LiturgicalCalendar(2055, "roman")
    assert LiturgicalCalendar(2056, "roman")
    assert LiturgicalCalendar(2057, "roman")
    assert LiturgicalCalendar(2058, "roman")
    assert LiturgicalCalendar(2059, "roman")
    assert LiturgicalCalendar(2060, "roman")
    assert LiturgicalCalendar(2061, "roman")
    assert LiturgicalCalendar(2062, "roman")
    assert LiturgicalCalendar(2063, "roman")
    assert LiturgicalCalendar(2064, "roman")
    assert LiturgicalCalendar(2065, "roman")
    assert LiturgicalCalendar(2066, "roman")
    assert LiturgicalCalendar(2067, "roman")
    assert LiturgicalCalendar(2068, "roman")
    assert LiturgicalCalendar(2069, "roman")
    assert LiturgicalCalendar(2070, "roman")
    assert LiturgicalCalendar(2071, "roman")
    assert LiturgicalCalendar(2072, "roman")
    assert LiturgicalCalendar(2073, "roman")
